@@ -6,7 +6,7 @@ from .optimum import Optimum
 from .utils import (
     convert2onnx,
     upload_outputs,
-    platform_type_infer,
+    infer_platform_type,
     JSONConfig,
     JSONOutput,
 )
@@ -23,7 +23,7 @@ if __name__ == "__main__":
 
     args = parser.parse_args()
 
-    config = JSONConfig(args.path, platform_type_infer(args.path))
+    config = JSONConfig(args.path, infer_platform_type(args.path))
     onnx_model = convert2onnx(
         config["platform_type"],
         config["model_path"],
